==> nextcloud-29.0.12.tgz: nextcloud/apps/circles/l10n/it.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Hai eliminato {circle}",
    "{author} deleted {circle}" : "{author} ha eliminato {circle}",
    "You removed {member} from {circle}" : "Hai rimosso {member} da {circle}",
    "You joined {circle}" : "Sei entrato a far parte di {circle}",
    "{member} joined {circle}" : "{member} si è unito a {circle}",
    "You accepted the invitation to join {circle}" : "Hai accettato l'invito per unirti {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha accettato l'invito per unirsi a {circle}",
    "You added {member} as member to {circle}" : "Hai aggiunto {member} come membro di {circle}",
    "You have been added as member to {circle} by {author}" : "Sei stato aggiunto come membro a {circle} da {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} è stato aggiunto come membro a {circle} da {author}",
    "You added {external} to {circle}" : "Hai aggiunto {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} è stato aggiunto a {circle} da {author}",
    "You accepted {member}'s request to join {circle}" : "Hai accettato la richiesta di {member} per unirti a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "La tua richiesta di unirti a {circle} è stata accettata da {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La richiesta di {member} di unirsi a {circle} è stata accettata da {author}",
    "You left {circle}" : "Hai abbandonato {circle}",
    "{member} left {circle}" : "{member} ha abbandonato {circle}",
    "You declined the invitation to join {circle}" : "Hai rifiutato l'invito per unirti a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rifiutato un invito per unirsi a {circle}",
    "You cancelled your request to join {circle}" : "Hai annullato la tua richiesta di unirti a {circle}",
    "You have been removed from {circle} by {author}" : "Sei stato rimosso da {circle} da {author}",
    "{member} has been removed from {circle} by {author}" : "{member} è stato rimosso da {circle} da {author}",
    "You removed {external} from {circle}" : "Hai rimosso {external} da {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} è stato rimosso da {circle} da {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Hai annullato l'invito di {member} per unirti a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "La tua richiesta di unirti a {circle} è stata annullata da {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha annullato l'invito di {member} per unirsi a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hai scartato la richiesta di {member} per unirsi a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "La tua richiesta di unirti a {circle} è stata scartata da {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La richiesta di {member} di unirsi a {circle} è stata scartata da {author}",
    "You invited {member} to join {circle}" : "Hai invitato {member} a unirsi a {circle}",
    "You have been invited to join {circle} by {author}" : "Sei stato invitato a unirti a {circle} da {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} è stato invitato a unirsi a {circle} da {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Hai modificato il livello di {member} in {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha modificato il tuo livello in {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha modificato il livello di {member} in {circle} a %1$s",
    "You sent a request to join {circle}" : "Hai inviato una richiesta di unirti a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha inviato una richiesta di unirsi a {circle}",
    "You are the new owner of {circle}" : "Sei il nuovo proprietario di {circle}",
    "{member} is the new owner of {circle}" : "{member} è il nuovo proprietario di {circle}",
    "Shared to Circles" : "Condivisi con cerchie",
    "Single" : "Singola",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visibile",
    "Open" : "Apri",
    "Invite" : "Invita",
    "Friends" : "Amici",
    "Password protected" : "Protetto da password",
    "No Owner" : "Nessun proprietario",
    "Hidden" : "Nascosta",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Radice",
    "Federated" : "Federata",
    "Mount point" : "Punto di mount",
    "Nextcloud Account" : "Account Nextcloud",
    "Nextcloud Group" : "Gruppo Nextcloud",
    "Email address" : "Indirizzo email",
    "Contact" : "Contatto",
    "Circle" : "Cerchia",
    "Nextcloud App" : "Applicazione Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderatore",
    "Admin" : "Amministratore",
    "Owner" : "Proprietario",
    "%s shared »%s« with you." : "%s ha condiviso «%s» con te.",
    "%s shared »%s« with \"%s\"." : "%s ha condiviso »%s« con \"%s\".",
    "%s on %s" : "%s su %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso »%2$s« con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso »%2$s« con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access »%1$s« shared to you by %2$s" : "Password per accedere a «%1$s» condivisa con te da %2$s",
    "Password to access »%s«" : "Password per accedere a «%s»",
    "It is protected with the following password:" : "È protetta con la password seguente:",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
    "Open »%s«" : "Apri «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s ha condiviso diversi file con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s ha condiviso diversi file con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access files shared to you by %1$s" : "Password per accedere ai file condivisi con te da %1$s",
    "Password to access files" : "Password per accedere ai file",
    "%s shared multiple files with \"%s\"." : "%s ha condiviso più file con \"%s\".",
    "%s shared multiple files with you." : "%s ha condiviso più file con te.",
    "Boot up" : "Avvia",
    "Nextcloud Initialization" : "Inizializzazione Nextcloud",
    "Circles App Initialization" : "Inizializzazione app Cerchie",
    "Fresh installation status" : "Stato nuova installazione",
    "Building Local Database" : "Costruzione database locale",
    "Testing Basic Circle Creation" : "Test creazione cerchia di base",
    "Adding local users and moderators" : "Aggiunta di utenti locali e moderatori",
    "Files" : "File",
    "This feature is not available for personal circles" : "Questa funzionalità non è disponibile nelle cerchie personali",
    "This member is not a moderator" : "Questo membro non è un moderatore",
    "Insufficient privileges" : "Permessi insufficienti",
    "This member does not exist" : "Questo membro non esiste",
    "Level cannot be changed for this type of member" : "Il livello non può essere modificato per questo tipo di membro",
    "You are already a member of this circle" : "Sei già un membro di questa cerchia",
    "You have been blocked from this circle" : "Sei stato bloccato da questa cerchia",
    "The account is already a member of this circle" : "L'account è già membro di questa cerchia",
    "The account has already been invited into this circle" : "L'account è già stato invitato in questa cerchia",
    "Accept" : "Accetta",
    "Refuse" : "Rifiuta",
    "%s" : "%s",
    "%s owned by %s" : "%s posseduto da %s",
    "%s shared a file with \"%s\"." : "%s ha condiviso un file con \"%s\".",
    "%s shared a file with you." : "%s ha condiviso un file con te.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso qualcosa con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso qualcosa con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access content shared with you by %1$s" : "Password per accedere ai contenuti condivisi con te da %1$s",
    "Password to access content" : "Password per accedere ai contenuti",
    "Bring cloud-users closer together." : "Avvicina gli utenti del cloud",
    "No files in here" : "Nessun file qui",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "You are now a member of the Circle \"%2$s\"" : "Ora sei membro della cerchia \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Sei stato invitato da %1$s nella cerchia \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha inviato una richiesta per essere membro della cerchia \"%2$s\"",
    "Leave the circle" : "Abbandona la cerchia"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.10.tgz: nextcloud/apps/circles/l10n/it.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Hai eliminato {circle}",
    "{author} deleted {circle}" : "{author} ha eliminato {circle}",
    "You removed {member} from {circle}" : "Hai rimosso {member} da {circle}",
    "{author} removed {member} from {circle}" : "{author} ha rimosso {member} da {circle}",
    "You joined {circle}" : "Sei entrato a far parte di {circle}",
    "{member} joined {circle}" : "{member} si è unito a {circle}",
    "You accepted the invitation to join {circle}" : "Hai accettato l'invito per unirti {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha accettato l'invito per unirsi a {circle}",
    "You added {member} as member to {circle}" : "Hai aggiunto {member} come membro di {circle}",
    "You have been added as member to {circle} by {author}" : "Sei stato aggiunto come membro a {circle} da {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} è stato aggiunto come membro a {circle} da {author}",
    "You added {external} to {circle}" : "Hai aggiunto {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} è stato aggiunto a {circle} da {author}",
    "You accepted {member}'s request to join {circle}" : "Hai accettato la richiesta di {member} per unirti a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "La tua richiesta di unirti a {circle} è stata accettata da {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La richiesta di {member} di unirsi a {circle} è stata accettata da {author}",
    "You left {circle}" : "Hai abbandonato {circle}",
    "{member} left {circle}" : "{member} ha abbandonato {circle}",
    "You declined the invitation to join {circle}" : "Hai rifiutato l'invito per unirti a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rifiutato un invito per unirsi a {circle}",
    "You cancelled your request to join {circle}" : "Hai annullato la tua richiesta di unirti a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} ha cancellato la richiesta di ingresso a {circle}",
    "You have been removed from {circle} by {author}" : "Sei stato rimosso da {circle} da {author}",
    "{member} has been removed from {circle} by {author}" : "{member} è stato rimosso da {circle} da {author}",
    "You removed {external} from {circle}" : "Hai rimosso {external} da {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} è stato rimosso da {circle} da {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Hai annullato l'invito di {member} per unirti a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "La tua richiesta di unirti a {circle} è stata annullata da {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha annullato l'invito di {member} per unirsi a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hai scartato la richiesta di {member} per unirsi a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "La tua richiesta di unirti a {circle} è stata scartata da {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La richiesta di {member} di unirsi a {circle} è stata scartata da {author}",
    "You invited {member} to join {circle}" : "Hai invitato {member} a unirsi a {circle}",
    "You have been invited to join {circle} by {author}" : "Sei stato invitato a unirti a {circle} da {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} è stato invitato a unirsi a {circle} da {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Hai modificato il livello di {member} in {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha modificato il tuo livello in {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha modificato il livello di {member} in {circle} a %1$s",
    "You sent a request to join {circle}" : "Hai inviato una richiesta di unirti a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha inviato una richiesta di unirsi a {circle}",
    "You are the new owner of {circle}" : "Sei il nuovo proprietario di {circle}",
    "{member} is the new owner of {circle}" : "{member} è il nuovo proprietario di {circle}",
    "Single" : "Singola",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visibile",
    "Open" : "Apri",
    "Invite" : "Invita",
    "Friends" : "Amici",
    "Password protected" : "Protetto da password",
    "No Owner" : "Nessun proprietario",
    "Hidden" : "Nascosta",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Radice",
    "Federated" : "Federata",
    "Mount point" : "Punto di mount",
    "Nextcloud Account" : "Account Nextcloud",
    "Nextcloud Group" : "Gruppo Nextcloud",
    "Email address" : "Indirizzo email",
    "Contact" : "Contatto",
    "Circle" : "Cerchia",
    "Nextcloud App" : "Applicazione Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderatore",
    "Admin" : "Amministratore",
    "Owner" : "Proprietario",
    "%s shared »%s« with you." : "%s ha condiviso «%s» con te.",
    "%s shared »%s« with \"%s\"." : "%s ha condiviso »%s« con \"%s\".",
    "%s on %s" : "%s su %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso »%2$s« con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso »%2$s« con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access »%1$s« shared to you by %2$s" : "Password per accedere a «%1$s» condivisa con te da %2$s",
    "Password to access »%s«" : "Password per accedere a «%s»",
    "It is protected with the following password:" : "È protetta con la password seguente:",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
    "Open »%s«" : "Apri «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s ha condiviso diversi file con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s ha condiviso diversi file con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access files shared to you by %1$s" : "Password per accedere ai file condivisi con te da %1$s",
    "Password to access files" : "Password per accedere ai file",
    "%s shared multiple files with \"%s\"." : "%s ha condiviso più file con \"%s\".",
    "%s shared multiple files with you." : "%s ha condiviso più file con te.",
    "Boot up" : "Avvia",
    "Nextcloud Initialization" : "Inizializzazione Nextcloud",
    "Circles App Initialization" : "Inizializzazione app Cerchie",
    "Fresh installation status" : "Stato nuova installazione",
    "Building Local Database" : "Costruzione database locale",
    "Testing Basic Circle Creation" : "Test creazione cerchia di base",
    "Adding local users and moderators" : "Aggiunta di utenti locali e moderatori",
    "Files" : "File",
    "This feature is not available for personal circles" : "Questa funzionalità non è disponibile nelle cerchie personali",
    "This member is not a moderator" : "Questo membro non è un moderatore",
    "Insufficient privileges" : "Permessi insufficienti",
    "This member does not exist" : "Questo membro non esiste",
    "Level cannot be changed for this type of member" : "Il livello non può essere modificato per questo tipo di membro",
    "You are already a member of this circle" : "Sei già un membro di questa cerchia",
    "You have been blocked from this circle" : "Sei stato bloccato da questa cerchia",
    "The account is already a member of this circle" : "L'account è già membro di questa cerchia",
    "The account has already been invited into this circle" : "L'account è già stato invitato in questa cerchia",
    "Accept" : "Accetta",
    "Refuse" : "Rifiuta",
    "%s" : "%s",
    "%s owned by %s" : "%s posseduto da %s",
    "%s shared a file with \"%s\"." : "%s ha condiviso un file con \"%s\".",
    "%s shared a file with you." : "%s ha condiviso un file con te.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso qualcosa con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso qualcosa con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
    "Password to access content shared with you by %1$s" : "Password per accedere ai contenuti condivisi con te da %1$s",
    "Password to access content" : "Password per accedere ai contenuti",
    "Bring cloud-users closer together." : "Avvicina gli utenti del cloud",
    "No files in here" : "Nessun file qui",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "Shared to Circles" : "Condivisi con cerchie",
    "You are now a member of the Circle \"%2$s\"" : "Ora sei membro della cerchia \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Sei stato invitato da %1$s nella cerchia \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha inviato una richiesta per essere membro della cerchia \"%2$s\"",
    "Leave the circle" : "Abbandona la cerchia"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
